/**
 * apeman app to send html response.
 * @function apemanAppHtml
 * @param {object} [options] - Optional settings.
 * @param {string} [options.contentType='application/html; charset=UTF-8;'] - Content type for header
 * @returns {function} - Defined app function.
 */

'use strict'

const co = require('co')

/** @lends create */
function create (options = {}) {
  let contentType = options.contentType || 'text/html; charset=UTF-8;'

  let app = co.wrap(function * htmlApp (ctx, next) {
    if (ctx.html) {
      yield next()
      return
    }

    ctx.html = function html (data) {
      if (typeof data === 'object') {
        try {
          data = JSON.stringify(data)
        } catch (e) {
          // Do nothing
        }
      }
      let body = String(data).trim()
      let hasDocType = /<!DOCTYPE\shtml>/.test(body)
      if (!hasDocType) {
        body = '<!DOCTYPE html>' + body
      }
      ctx.set('Content-Length', Buffer.byteLength(body))
      ctx.set('Content-Type', contentType)
      ctx.body = body
    }
    yield next()
  })

  Object.assign(app, {
    // Description of this app.
    $desc: 'Define html response function.'
  })

  return app
}

module.exports = create
