/**
 * Test case for create.
 * Runs with mocha.
 */
'use strict'

const create = require('../lib/create.js')
const apemanport = require('apemanport')
const co = require('co')
const apemanApp = require('apeman-app')
const assert = require('assert')
const apemanrequest = require('apemanrequest')

describe('create', () => {
  let server, port
  let request = apemanrequest.create({})
  before(() => co(function * () {
    port = yield apemanport.find()
    let app = create({})
    assert.ok(app)
    server = yield apemanApp('testing-app', {
      port,
      configuration: {
        $apps: {
          'testing-app': {
            '/': [
              app,
              co.wrap(function * handle (ctx) {
                ctx.html('<html>Yeah!</html>')
              })
            ]
          }
        }
      }
    })
  }))

  after(() => co(function * () {
    yield server.close()
  }))

  it('Create an app.', () => co(function * () {
    let res = yield request({
      method: 'GET',
      url: `http://localhost:${port}/`
    })
    let { body } = res
    assert.equal(res.statusCode, 200)
    assert.equal(body, '<!DOCTYPE html><html>Yeah!</html>')
  }))
})

/* global describe, before, after, it */
